#ifndef BEZIER_H
#define BEZIER_H

// Mini algebra.h for standalone version.
#ifndef ALGEBRA_H
class vector2d
{
public:
    float x, y;
};

class vector3d
{
public:
    vector3d() {}
    vector3d( float _x, float _y, float _z ) : x( _x ), y( _y ), z( _z ) {}
    float x, y, z;
};
#endif

//
// TPatchVertex
//
// 3x3 array of vector3d's define a patch vertex.  This provides sharing of vertices and control points
// between seperate patches in a 'patch mesh'.  An improved version might implement this higher level
// structure and provide sharing of calculated surface points, since there's currently some redundant work.
//
// The middle vert (vert[1][1]) is the vertex, the surrounding verts are control points.
// The four corners of the patches fall on their patch vertices.  The curve is adjusted by the control points 
// but doesn't neccessarily intersect them.
typedef vector3d TPatchVertex[3][3];

struct SPatch
{
    int Verts[4];       // index into vertex pool ordered clockwise from UL
};

// Debugging tools.
extern bool DrawCtrl, DrawLines, DrawPolys;

// Number of patch point calculations per frame.
extern int PointCount;  

// Draw a patch using the 3D Device.  Generates vertices and 0 to 1 texture coordinates.
void DrawPatch( LPDIRECT3DDEVICE7 pd3dDevice, SPatch* Patch, TPatchVertex* VertexPool, float Subdiv );

#endif